@@ -462,7 +462,7 @@ sub list_tables
       #
       # "jsiracusa                       ".test
 
-      if($item =~ /^(?: "(?:""|[^"]+)+" | [^".]+ ) \. (?: "((?:""|[^"]+)+)" | (\w+) )/x)
+      if($item =~ /^(?: "(?:""|[^"]+)+" | [^".]+ ) \. (?: "((?:""|[^"]+)+)" | ([^"]+) )$/x)
       {
         push(@tables, defined $1 ? $1 : $2);
       }
